Struct ark_poly::evaluations::multivariate::multilinear::DenseMultilinearExtension [−][src]
Stores a multilinear polynomial in dense evaluation form.
Fields
evaluations: Vec<F>The evaluation over {0,1}^num_vars
num_vars: usizeNumber of variables
Implementations
Construct a new polynomial from a list of evaluations where the index
represents a point in {0,1}^num_vars in little endian form. For example, 0b1011 represents P(1,1,0,1)
Construct a new polynomial from a list of evaluations where the index
represents a point in {0,1}^num_vars in little endian form. For example, 0b1011 represents P(1,1,0,1)
Relabel the point inplace by switching k scalars from position a to position b, and from position b to position a in vector.
This function turns P(x_1,...,x_a,...,x_{a+k - 1},...,x_b,...,x_{b+k - 1},...,x_n)
to P(x_1,...,x_b,...,x_{b+k - 1},...,x_a,...,x_{a+k - 1},...,x_n)
Returns an iterator that iterates over the evaluations over {0,1}^num_vars