Struct ark_poly::evaluations::multivariate::multilinear::SparseMultilinearExtension [−][src]
pub struct SparseMultilinearExtension<F: Field> { pub evaluations: BTreeMap<usize, F>, pub num_vars: usize, // some fields omitted }
Stores a multilinear polynomial in sparse evaluation form.
Fields
evaluations: BTreeMap<usize, F>tuples of index and value
num_vars: usizenumber of variables
Implementations
pub fn from_evaluations<'a>(
num_vars: usize,
evaluations: impl IntoIterator<Item = &'a (usize, F)>
) -> Self[src]pub fn rand_with_config<R: Rng>(
num_vars: usize,
num_nonzero_entries: usize,
rng: &mut R
) -> Self[src]
pub fn rand_with_config<R: Rng>(
num_vars: usize,
num_nonzero_entries: usize,
rng: &mut R
) -> Self[src]Outputs an l-variate multilinear extension where value of evaluations are sampled uniformly at random.
The number of nonzero entries is num_nonzero_entries and indices of those nonzero entries are distributed uniformly at random.
Note that this function uses rejection sampling. As number of nonzero entries approach 2 ^ num_vars,
sampling will be very slow due to large number of collisions.
Convert the sparse multilinear polynomial to dense form.