pub trait Term: Clone + PartialOrd + Ord + PartialEq + Eq + Hash + Default + Debug + Deref<Target = [(usize, usize)]> + Send + Sync + CanonicalSerialize + CanonicalDeserialize {
    fn new(term: Vec<(usize, usize)>) -> Self;
    fn degree(&self) -> usize;
    fn vars(&self) -> Vec<usize>;
    fn powers(&self) -> Vec<usize>;
    fn is_constant(&self) -> bool;
    fn evaluate<F: Field>(&self, p: &[F]) -> F;
}
Describes the interface for a term (monomial) of a multivariate polynomial.

Required Methods

Create a new Term from a list of tuples of the form (variable, power)

Returns the total degree of self. This is the sum of all variable powers in self

Returns a list of variables in self

Returns a list of the powers of each variable in self

Returns whether self is a constant

Evaluates self at the point p.

Implementors